# HIV indicators - natural course of an HIV epidemic or results of sociobehavioral changes?

## Difficulty in choosing a basic HIV indicator to compare HIV epidemics across countries and across time

What HIV indicators should we use to compare the epidemics across countries & what HIV indicators give us a sense of where the epidemic is? 

### HIV incidence:
- Expectation: Lower numbers of new HIV infections per year is a good sign
- Contextualization: HIV incidence depends on multiple factors and cannot be directly compared across countries or time
- Example: Country A has a slightly higher HIV incidence than country B, but country A has 100% higher HIV prevalence than country B, how can we tell which is better in terms of the HIV epidemic?

### HIV prevalence:
- Expectation: Lower HIV prevalence means less people living with HIV and should be a good sign
- Contextualization: HIV prevalence depends on both new HIV infections and mortality of HIV/AIDS patients making it difficult for direct comparison
- Example: Take again country A with 100% higher HIV prevalence than country B, but country A has very little HIV/AIDS mortality thanks to widespread use of ART while country B has very little use of ART and relatively high HIV mortality. Again how can we tell which is better?

### HIV mortality:
- Expectation: Lower HIV mortality means less people are dying of HIV/AIDS
- Contextualization: HIV mortality is depends on HIV prevalence and ART coverage
- Example: Country A above has little HIV/AIDS mortality for its HIV prevalence, but country B has similar HIV mortality simply because HIV prevalence is low

## A very simple compartmental model for HIV

### SID model:
Of course many simplifying assumptions are made here (that are not correct in real life):
- No births (but we focus on 15-49 population anyways)
- No deaths other than HIV/AIDS related deaths (this can probabbly be hedged)
- Binary infectious status based on ART
- etc (anything not specifically discussed below is assumed not to exist..)

#### S --> Susceptible state:

An S individual is simply someone susceptible to the disease, meaning anyone in the population who is not immune to the disease.

#### I --> Infectious state:

Once an individual is exposed to the disease, he will become infectious (unless suppressed with ART).

#### D --> Death state:

HIV infections eventually become AIDS and lead to death (unless suppressed with ART).

### SID compartmental model disease dynamics

#### S → I

##### Individual-level

Going from S to I for an indivudal in a particular year depends on three things:

- the proportion of infectious people in the population that year: 

$$i(t) = Prevalence$$

Although with ART the equation may become:

$$i(t) = (1- ART_{coverage}) * Prevalence$$

- the number of exposure events the individual has per year (this means number of drug injections, number of sexual partners, etc etc):

$$r$$

- the chance for an S to contract the disease after such an exposure event : 

$$\rho$$ 

which combines many factors into one, including:

- Male circumcision
- Use of condoms
- Other STDs
- Use of $PrEP$
- It can also incluse $ART_{coverage}$ (if not already included above)
- and so on..

We can combine the last two into 

$$\beta = \rho*r$$

##### Population level

On a population-level however, the number of S that will become I also depends on the proportion of S itself in the population (obviously if there are no $S$ in the first place, no one will can become $I$).

Note, any factor impacting susceptibility of an individual ($PrEP$, condom use, etc) is already factored into $\beta$.

So we add the following requirement:

- the proportion of susceptible people in the population that year: 

$$s(t) = 1 - HIV_{Prevalence}$$

So the change in the number of S in a population in a given year is :

$$-\beta*i(t)*s(t)$$

and so HIV incidence can be given by:

$$HIV_{Incidence} = \beta*i(t)*s(t)$$

$$\iff HIV_{Incidence} = \beta * HIV_{Prevalence} * (1-HIV_{Prevalence})$$

or if we take into account $ART_{coverage}$ separately:

$$\iff HIV_{Incidence} = \beta * (1-ART_{coverage}) * HIV_{Prevalence} * (1-HIV_{Prevalence})$$

## A new HIV indicator to compare across countries

As we have data from UNAIDS on $ART_{coverage}$, $HIV_{Incidence}$, and $HIV_{Prevalence}$ from 1990 on, we can easily calculate this $\beta$ as follows:

$$\beta = \frac{HIV_{Incidence}}{HIV_{Prevalence}-HIV_{Prevalence}^2}$$

$$or$$

$$\beta = \frac{HIV_{Incidence}}{(1-ART_{coverage})*(HIV_{Prevalence}-HIV_{Prevalence}^2)}$$

And from the description above, $\beta$ can be a proxy factor representing all socio-behavioral characteristics.
