---
output: pdf_document
title: 1_METHODS
bibliography: [0_references.bib]
---

- [1.1. Data](#11-data)
- [1.2. Ethics approval](#12-ethics-approval)
- [1.3. Analysis](#13-analysis)
  - [$\S$ 1.3.1 – Sociobehavioral characteristics](#s-131--sociobehavioral-characteristics)
  - [$\S$ 1.3.3 . Course of HIV epidemics and effective contact rate $\beta$](#s-133--course-of-hiv-epidemics-and-effective-contact-rate-beta)
- [1.4. Tools and software](#14-tools-and-software)
- [References](#references)

## 1.1. Data

The DHS has been gathering nationally representative data at regular intervals since its inception in 1984 (USAID, 2020b). The data span social, behavioral, geographic, economic, and health related issues, including HIV-related data and sexual behavior, especially since the emergence of HIV/AIDS as a public health crisis [@Curtisii22]. This has naturally made the DHS the primary source of data for this study.

Data was collected with the intent of including all indicators possibly influencing the risk of acquiring HIV for individuals aged 15-49 years old, or possibly affecting the course of HIV epidemics on local, regional, and national levels. We used the StatCompiler tool (USAID, 2020a) to collect the surveys of 29 SSA countries between 2000 and 2018, that were available up to September 2020. While we aimed to go as far back in time as possible to include the emergence of HIV, earlier surveys lacked reliability in the specific indicators of interest, resulting in a total of 80 surveys collected, with each of the 29 countries having between 1 and 6 surveys over that time period.

Similarly as Merzouki et. al. [-@Merzouki2021Jan], we retained only those variables that varied significantly across regions and did not strongly correlate with other variables. The data were represented as percentages, with mean number of sexual partners in lifetime scaled using min-max normalization. The resulting 46 attributes are shown in Table 1 and create a 46 dimensional image of each survey collected, in turn each representing a snapshot of a country at a specific point in time.

While most of these attributes were collected using the DHS StatCompiler tool [@BibEntry2020Aug], latent variables were either replaced with alternative sources in the cases of male circumcision [@IHME_MC], urban/rural divide [@worldbank_2020_rurality], Gini coefficient [@worldbank_2020_wealth], ART coverage [@worldbank_2020_ART], and religion [@COW]. Other latent variables for which alternative sources were unavailable were imputed using additional topic-related variables available from the DHS using multiple iterative chained equations – while the detailed analysis of the imputation technique lies outside the scope of this study, all details can be found in Annex 1. Finally, estimates for national HIV incidence and prevalence between the years 1990 and 2019 were obtained from the latest (2020) UNAIDS’ AIDSinfo [UNAIDS](https://aidsinfo.unaids.org/).

## 1.2. Ethics approval

This study uses publicly accessible data aggregated through StatCompiler, the World Bank, healthdata.org, Correlates of War, and UNAIDS’ AIDSinfo. No ethics approval was needed from our side.

## 1.3. Analysis

### $\S$ 1.3.1 – Sociobehavioral characteristics

We reduced the dimensionality of each survey using Principal Component Analysis (PCA) [@PearsonPCA]. PCA allows the transformation of the 46 original dimensions of each survey into a smaller subset of uncorrelated indices called principle components (PCs) along which the variation of data is maximized and information loss is minimized [@Jolliffe2016]. As the PCs consist of a linear combination of the initial 46 dimensions, they can be interpreted in terms of the original demographic, socioeconomic, and behavioral characteristics, and can thus be used to construe sociobehavioral heterogeneity or homogeneity across SSA, both spatially and over time. To capture the longitudinal trends in our dataset, and in an effort to facilitate comparison with the results obtained by Merzouki et. al. [-@Merzouki2021Jan], we obtained the rotation matrix using only the most recent surveys i.e. only those collected since 2015. This rotation matrix was then used to project all other surveys onto the dimensionally reduced PCA space.

While the first 2 PCs, which explain the most variance, are used to represent the axes on a 2D-space to provide a visual perspective of similarity between the surveys, we used a consensus clustering method to provide a more robust means of identifying groups of similar surveys in terms of sociobehavioral characteristics. We predefined 3 as the number of clusters to obtain as was obtained by Merzouki et. al. [-@Merzouki2021Jan]. The consensus clustering method consisted of three hierarchical clustering and three k-means clustering [@kmeans] partitions, each run on a different number of PCs: the first with only the 2 main PCs, the second with the $n$ PCs that accounted for $95\%$ of the overall variance, and the third with the entire 46 dimensional data set. We identified longitudinal trends and determined the key sociobehavioral characteristics driving change by visualizing both the trajectories of countries and of the cluster centroids on the 2 dimensional PCA space over time. Finally, we compared the HIV incidence of countries between these clusters by visualizing the HIV incidence using box plots.

### $\S$ 1.3.3 . Course of HIV epidemics and effective contact rate $\beta$

We calculated for each country their effective contact rate $\beta$ from the estimates of the basic HIV indicators of incidence and prevalence - details of the derivation of this indicator can be found in Annex 2. The effective contact rate $\beta$ is a measure of incidence given the prevalence (i.e. the number of new infections given the local context of the HIV epidemic) and is effectively both a proxy for the sociobehavioral characteristics of the population while also directly gauging the transmission dynamics of HIV within that population, doing so independently of the local context of the HIV epidemic. We compared the progression of the effective contact rates since 1990 across SSA to that of HIV incidence and compared them across the clusters obtained previously and visualized them again with box plots. [@IHME_MC]

Lastly, we identified clusters of countries based on the evolution of their effective contact rates by first scaling the time-series such that they had zero mean and unit variance (following the assumption that their amplitudes are not as informative as their relative shapes) and used k-means clustering [@kmeans] with a dynamic time warping barycenter averaging algorithm [@tsclustering]. We measured the quality of the clustering results using a silhouette score [@ROUSSEEUW198753] and determined the optimal number of clusters. We compared this new set of clusters with the ones previously obtained using sociobehavioral characteristics and compare their respective HIV incidence and effective contact rates.

## 1.4. Tools and software

We used the open source Python language [@van1995python], complemented by Pandas [@mckinney-proc-scipy-2010], NumPy [@2020NumPy-Array], SciPy [@2020SciPyNMeth], TSLearn [@JMLR:v21:20-091], Scikit-learn [@JMLR:v12:pedregosa11a] for all data aggregating, data wrangling, and data analysis, and used Plotly [@plotly] for data visualizations. All code, data, and other material are available on RenkuLab (https://renkulab.io/gitlab/jeffrey.post/ssa_hiv_ml).

## References
