---
output: pdf_document
title: 3_DISCUSSION
bibliography: [0_references.bib]
---

Using PCA and consensus clustering we found three groups of countries with similar sociobehavioral characteristics, with heterogeneity across clusters being explained for the most part ($73.2\%$) by religion, rates of male circumcision, women empowerment, rates of HIV testing, acceptance towards PLWHA, rurality, literacy, knowledge about HIV, and ART coverage. We found HIV incidence to be similar between countries of the same clusters but dissimilar across clusters, in line with the findings of Merzouki et. al. [-@Merzouki2021Jan]. From a longitudinal perspective, we found that while overall HIV incidence rates have significantly decreased across SSA over the 2000-2019 time period, the dissimilar levels persisted across the clusters while levels remained similar within clusters. On the other hand, the effective contact rates, while also decreasing significantly, were remarkably similar across clusters and over time, although they varied substantially within clusters. Over the same time period, heterogeneity on the sociobehavioral space has slightly increased across clusters but homogeneity within clusters remained.

The difference in levels of HIV incidence across the three clusters has been present since at least the early 1990s. Further, the effective contact rates have evolved in a similar manner across clusters over the same period. The different levels of HIV epidemics seen today across the clusters are therefore unlikely to be a direct result of the different evolutions of the clusters as seen on the sociobehavioral space since 2000, and are more likely to be the result of the different initial conditions in which the early years of the HIV epidemics took place. This is perfectly exemplified by Chad, Cote d’Ivoire, and Malawi, who have an almost identical progression of their effective contact rates between 1990 and 2019, but the very different initial conditions in 1990 (HIV incidence of 2.53 per 1000 for Chad, 9.73 per 1000 for Cote d’Ivoire, and 19.51 per 1000 for Malawi) have lead to large differences in levels of their respective epidemics to this day.

Small differences in effective contact rates in nascent epidemics can lead to very different levels of epidemics over time [@00042560-199703010-00009] [Annex 3]. It can thus be hypothesized that the starting effective contact rates of the three clusters were slightly different and the cause of the long-term differences over the course of the entire epidemic. There is some evidence of this in the effective contact rates of the early 1990s, where countries of the first cluster have a value of 0.30 compared to a slightly lower value of 0.27 and 0.26 for the other two clusters (countries of Sahel region and countries of central/western SSA respectively). Further work on reconstructing the effective contact rates of the 1980s across SSA would allow for better insight into this hypotheses.

Male circumcision has been shown to have a protective effect for seronegative men [@BAILEY2007643] [@10.1371/journal.pone.0125436] [@https://doi.org/10.1111/bju.14102], which could in turn reduce the effective contact rates, all else being equal, of countries with high rates of male circumcision versus countries with low rates of male circumcision. There is some evidence this could be one of the drivers of the early differences in effective contact rates across SSA, where countries with high rates of male circumcision (defined as over $75\%$) had on average an effective contact rate value lower by 0.0189 when compared to countries with low rates of male circumcision between the years 1990 and 2000. It should be noted that although high rates of male circumcision might have had a protective effect and reduced effective contact rates in nascent HIV epidemics, it is unclear whether voluntary medical male circumcision (VMMC) would have as much of an effect in later stages of epidemics where the effective contact rates have already been drastically lowered [@00042560-199703010-00009] - VMMC is a prevention priority of PEPFAR and has been an official recommendation of the WHO since 2007 [@00126334-201208153-00007].

Since 2005, SSA has also seen a large increase in coverage of ART with countries of the first cluster (eastern/southern SSA) reaching $81\%$ coverage while countries of the other two clusters increased to $52\%$ coverage on average. With high ART coverage being associated with declines in both risk of HIV acquisition and HIV mortality [@Tanser966], countries of the first cluster would be expected to see a quicker decrease in effective contact rates relative to countries of the other two clusters. Evidence of this can be seen in the latest figures from UNAIDS (from 2019) showing that countries of the first cluster (eastern/southern SSA) now have the lowest effective contact rates of SSA, with an average value of 0.044 compared to values of 0.052 and 0.054 for countries of western/central SSA and countries of Sahel region respectively. An almost $20\%$ lower value which, if sustained over time, is likely to lead to a more rapid control of the epidemic in those countries.

Our use of effective contact rates as a metric against which to gauge and compare progression of HIV epidemics across SSA is somewhat unusual. As public health programmes have been implemented, the importance of the criteria against which these are evaluated has increased  [@GALVANI2018e667]. Incidence-based criteria, which are easily understood, have typically been used, while incidence-to-mortality ratio, which follows the decline or increase of total number of people with HIV, or incidence-to-prevalence ratio, which tends to convey information about incidence reduction and survival extension, have increasingly been used [@10.1371/journal.pmed.1002678]. While these metrics are critical in order to prioritize focus and optimize programme and intervention implementations, they should not be used to compare different HIV epidemics without first an extensive look at each local context. The effective contact rate has the advantage of being able to extract and convey information about the level of the HIV epidemics given the local context and lends itself more easily as a comparison tool. It however relies on national estimates of incidence and prevalence which may produce large errors [@NSANZIMANA2017e457].

PCA has allowed us to visualize the complex patterns of behavior across SSA and their evolution over time and while we used more indicators than is typical [@Kidman791], [@Lakewe008669], [@Hajizadeh2014] to account for as many indicators that can influence the course of HIV epidemics, research has shown that using a subset of socioeconomic indicators can provide better results than a broader set [@Homenauth1046]. Further, the use of nationally aggregated data allows us to compare countries and clusters across SSA and are useful in the context of generalized epidemics, but are prone to ecological fallacy [@Levin2006] and overlook the salience of so-called high-risk key populations [@https://doi.org/10.1002/jia2.25750], despite the latter being of critical importance in the appropriate allocation of resources for effective interventions, especially so in the context of epidemiological transition and HIV incidence decline across SSA [@https://doi.org/10.1002/jia2.25727].

## References
